translate.search.indexing.PyLuceneIndexer

Package translate :: Package search :: Package indexing :: Module PyLuceneIndexer |
[hide private]
[frames] | no frames]

# Module PyLuceneIndexer

source code

interface for the PyLucene (v2.x) indexing engine

take a look at PyLuceneIndexer1.py for the PyLucene v1.x interface

Classes | [hide private]
| PyLuceneDatabase manage and use a pylucene indexing database
| PyLuceneHits an enquire object contains the information about the result of a request

Functions | [hide private]
is_available() | source code
_occur(required, prohibited) | source code
int |
_get_pylucene_version() get the installed pylucene version | source code
_escape_term_value(text) | source code

Variables | [hide private]
| __revision__ = `"$Id: PyLuceneIndexer.py 15717 2010-09-03 14:50`...``
| PyLucene = `lucene`
| _COMPILER = `'jcc'`
| UNNAMED_FIELD_NAME = `"FieldWithoutAName"`
| MAX_FIELD_SIZE = `1048576`

Imports: re, os, time, logging, lucene, CommonIndexer

Function Details | [hide private]

### _get_pylucene_version() | source code
get the installed pylucene version Returns: int 1 -> PyLucene v1.x / 2 -> PyLucene v2.x / 0 -> unknown

Variables Details | [hide private]

  ### __revision__ Value:
      "$Id: PyLuceneIndexer.py 15717 2010-09-03 14:50:28Z alaaosh $"